#include "StdAfx.h"
#include "WorkGroupActorEvent.h"
#include "WorkGroupController.h"

WorkGroupActorEvent::WorkGroupActorEvent(WorkGroupController* pController)
: m_pController(pController)
{
	g_pMessengerActor->RegisterObserver(this);
	g_pMessengerActor->GetWASActor()->RegisterObserver(this);
}

WorkGroupActorEvent::~WorkGroupActorEvent(void)
{
	g_pMessengerActor->GetWASActor()->UnRegisterObserver(this);	
	g_pMessengerActor->UnRegisterObserver(this);
}

bool WorkGroupActorEvent::OnGTWASActor_ResponseNameSearchList(IGTWASActor *pActor, trid_t trid, GTWASCallErrorCode eErrorCode, const NE_SEARCH_MEMBER_DATA_LIST &list)
{
	std::map<trid_t, MemberSearchAction>::const_iterator itr = m_nameSearchListTrid.find(trid);
	if (itr != m_nameSearchListTrid.end())
	{
		MemberSearchAction action = itr->second;

		m_nameSearchListTrid.erase(itr);

		if (eErrorCode == wasError_None)
		{
			MemberSearchResponseAction(action, list);
		}
		else
		{
			//ASSERT(FALSE);
		}
	}

	return false;
}

bool WorkGroupActorEvent::OnGTWASActor_ResponseMemberGroupList(IGTWASActor *pActor, trid_t trid, GTWASCallErrorCode eErrorCode,  const GT_ORG_GROUP_DATA_LIST &list)
{
	std::map<trid_t, MemberGroupListAction>::const_iterator itr = m_memberGroupListTrid.find(trid);
	if (itr != m_memberGroupListTrid.end())
	{
		MemberGroupListAction action = itr->second;

		m_memberGroupListTrid.erase(itr);

		if (eErrorCode == wasError_None)
		{
			MemberGroupListResponseAction(action, list);
		}
		else
		{
			//ASSERT(FALSE);
		}
	}

	return false;
}

void WorkGroupActorEvent::MemberSearchResponseAction( MemberSearchAction action, const NE_SEARCH_MEMBER_DATA_LIST &list )
{
	if (NULL == m_pController)
		return;

	switch (action)
	{
		case CHAT_ORG_SEARCH:
		case ORG_SEARCH:
		case DETAIL_ORG_SEARCH:
		case SEND_SMS_SEARCH:
		
			m_pController->AddNameSearchList(list, action);
			break;
		case ADD_USER_SEARCH:
			m_pController->AddUserDlgSearchList(list);
			break;
		
	}
}

void WorkGroupActorEvent::MemberGroupListResponseAction( MemberGroupListAction action, const GT_ORG_GROUP_DATA_LIST &list )
{
	if (NULL == m_pController)
		return;

	switch(action)
	{
		case ADD_WORKORGGROUP:
		case ADD_MAINORGGROUP:
			m_pController->AddORGGroupList(list, action);
			break;
		case ADD_WORKGROUP:
			m_pController->AddWorkGroupList(list);
			break;
	}
}

void WorkGroupActorEvent::MemberListResponseAction(const MemberListData& data, const NE_MEMBER_DATA_LIST &list )
{
	if (NULL == m_pController)
		return;

	switch(data.action)
	{
	case UPDATE_VIEW_DETAIL_ORG:
	case UPDATE_VIEW_ORG:
		m_pController->AddMemberList(list, data.action);
		break;
	case ADD_FAVORITE:
		m_pController->ReqeustAddBuddy(list, data.nGroupID);
		break;
	case MAKE_CHAT:
		m_pController->MakeMemberListChat(list);
		break;
	case SEND_MEMO:
		m_pController->SendMemberListMemo(list);
		break;
	case SEND_SMS:
		m_pController->SendMemberListSMS(list);
		break;
	}
}

bool WorkGroupActorEvent::OnGTWASActor_ResponseMemberList(IGTWASActor *pActor, trid_t trid, GTWASCallErrorCode eErrorCode, const NE_MEMBER_DATA_LIST &list)
{	
	std::map<trid_t, MemberListData>::const_iterator itr = m_memberListTrid.find(trid);
	if (itr != m_memberListTrid.end())
	{
		MemberListData data = itr->second;

		m_memberListTrid.erase(itr);

		if (eErrorCode == wasError_None)
		{
			MemberListResponseAction(data, list);
		}
		else
		{
			//ASSERT(FALSE);
		}
	}

	return false;
}

bool WorkGroupActorEvent::OnGTMessengerActor_UpdateNotBuddyUserStatus(IGTMessengerActor *pActor, LPCWSTR strBuddyID, int nUserStatus, LPCWSTR strNick, int nIPTStatus, int nFlag)
{
	if (NULL == m_pController)
		return true;

	if( nFlag & NOTIFY_FLAG_PRESENCE)
		m_pController->UpdateMemberStatus(strBuddyID, (GTUserStatusType)nUserStatus);

	if( nFlag & NOTIFY_FLAG_IPT && GET_APP()->IsAvailableIPT() )
		m_pController->UpdateMemberIPTStatus(strBuddyID, (NTIPTStatusType)nIPTStatus);

	return true;
}

bool WorkGroupActorEvent::OnGTMessengerActor_ResponseBuddyAction(IGTMessengerActor *pActor, const GT_BUDDY_RESULT_DATA& sData)
{
	if (NULL == pActor)
		return false;

	if (NULL == m_pController)
		return false;

	switch (sData.eAction)
	{
		case buddyAction_Add:
			//  ã  ߰ϴ   ޽  â  ־ Ѵ.
			if (sData.eError == buddyError_Max && sData.trid == m_buddyActionTrid)
			{
				GET_APP()->m_pMessageBoxManager->CreateMessageBox(m_pController->GetWorkGroupDlg(), LoadStringFromResource(IDS_STRING632));
				return false;
			}
			else if (sData.eError == buddyError_None)
			{
				// ã⿡ ģ /   'ã'ư ¸ ش.
				m_pController->RefreshButtonStatus();
			}
			break;

		case buddyAction_Delete:
			if (sData.eError == buddyError_None)
			{
				// ã⿡ ģ /   'ã'ư ¸ ش.
				m_pController->RefreshButtonStatus();
			}
			break;
	}

	return true;
}
